const svg = d3.select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const margin = {
    top: 50,
    right: 50,
    bottom: 50,
    left: 50,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const x = d3
    .scaleTime()
    .domain(d3.extent(data, (d) => d.Date))
    .range([0, innerWidth]);

  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Sales)])
    .nice()
    .range([innerHeight, 0]);

  const xAxis = (g) =>
    g.attr('transform', `translate(0,${innerHeight})`).call(
      d3
        .axisBottom(x)
        .ticks(width / 80)
        .tickSizeOuter(0),
    );

  const yAxis = (g) =>
    g
      .call(d3.axisLeft(y))
      .call((g) => g.select('.domain').remove())
      .call((g) =>
        g
          .select('.tick:last-of-type text')
          .clone()
          .attr('x', 3)
          .attr('text-anchor', 'start')
          .attr('font-weight', 'bold')
          .text('Sales'),
      );

  const area = d3
    .area()
    .curve(d3.curveMonotoneX)
    .x((d) => x(d.Date))
    .y0(y(0))
    .y1((d) => y(d.Sales));

  const line = d3
    .line()
    .curve(d3.curveMonotoneX)
    .x((d) => x(d.Date))
    .y((d) => y(d.Sales));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    )
    .append('g')
    .attr('class', 'grid')
    .call(
      d3.axisLeft(y).tickSize(-innerWidth).tickFormat(''),
    );

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    )
    .append('path')
    .datum(data)
    .attr('fill', 'steelblue')
    .attr('class', 'area')
    .attr('d', area);

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    )
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'steelblue')
    .attr('stroke-width', 2)
    .attr('class', 'line')
    .attr('d', line);

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${innerHeight + margin.top})`,
    )
    .call(xAxis);

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    )
    .call(yAxis);
};

d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/1c43c8e7888c5df109d46a4403734ba6/raw/d86330c694f6cf146073b47d448c19c57ed265f9/dominos.csv',
).then((data) => {
  data.forEach((d) => {
    d.Date = new Date(d.Date);
    d.Sales = +d.Sales;
  });
  render(data);
});
